@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-
+#include <cstring>
 #include <string>
 
 extern "C" {
@@ -51,7 +51,7 @@ ExtEditor::ExtEditor (PinyinProperties & props, Config & config)
     m_lua_plugin = ibus_engine_plugin_new ();
 
     gchar * path = g_build_filename (g_get_user_config_dir (),
-                                     "ibus", "pinyin", "base.lua", NULL);
+                                     ".ibus", "pinyin", "base.lua", NULL);
     loadLuaScript ( ".." G_DIR_SEPARATOR_S "lua" G_DIR_SEPARATOR_S "base.lua")||
         loadLuaScript (path) ||
         loadLuaScript (PKGDATADIR G_DIR_SEPARATOR_S "base.lua");
@@ -282,10 +282,10 @@ ExtEditor::processSpace (guint keyval)
 gboolean
 ExtEditor::processEnter(guint keyval)
 {
-    if ( !(keyval == IBUS_Return) )
+    if (keyval != IBUS_Return)
         return FALSE;
 
-    if ( m_text.length () == 0 )
+    if (m_text.length () == 0)
         return FALSE;
 
     Text text(m_text);
@@ -495,7 +495,7 @@ ExtEditor::updateStateFromInput (void)
     }
 
     if ( ! 'i' == m_text[0] ) {
-        g_warning ("i is expected in m_input string.\n");
+        g_warning ("i is expected in m_text string.\n");
         return FALSE;
     }
 
@@ -750,7 +750,7 @@ void
 ExtEditor::updateLookupTable (void)
 {
     if (m_lookup_table.size ()) {
-        Editor::updateLookupTable (m_lookup_table, TRUE);
+        Editor::updateLookupTableFast (m_lookup_table, TRUE);
     }
     else {
         hideLookupTable ();
